@@ -1,7 +1,9 @@
 #!/bin/sh
+# Copyright (C) 2008-2009  Wen-Yen Chuang <caleb AT calno DOT com>
+#
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License version 2 as
-# published by the Free Software Foundation.
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; version 2 of the License.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -11,8 +13,6 @@
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-#
-# Copyright (C) 2008  Wen-Yen Chuang <caleb AT calno DOT com>
 
 SHOWVTE_PROG_NAME=`grep PROGRAM_NAME src/config.h | tr -s ' ' ' ' | sed 's/^ //' | grep -v ^\/\/ | awk '{print $3}' | sed 's/"//g'`
 if [ "$SHOWVTE_PROG_NAME" = "" ]; then
@@ -28,6 +28,11 @@ fi
 
 echo echo Configuration of $SHOWVTE_PROG_NAME $SHOWVTE_VERSION:
 
+if [ "$EVILVTE" = "min" ]; then
+  echo echo [1m[31mDisable everything.[m
+  echo exit
+fi
+
 exit
 
 if [ "$1" = "-v" ]; then
